@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-17e09be3bfe5a8dac304d4ad10626a4c
-key: aws_4UUKLMSCnZg23hhYv9Alwo
+id: aws-0.13.0-cb423743fad8b7d9c51f923d4c84948f
+key: aws_8FAC0NmyEj63KMf0rXlBup
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,10 +55,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-4UUKLMSCnZg23hhYv9Alwo
+hs-libraries: HSaws-0.13.0-8FAC0NmyEj63KMf0rXlBup
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -67,31 +67,31 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
-    conduit-extra-1.1.9.2-79e9518024a2df5c3adcf7d7df9fbea5
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
+    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-e4b3137b3a617f6e2e89e01e265fce1e
+    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.3-d17252c3c6d15542c81680ee4120c0b6
+    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
 haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
 haddock-html: /usr/share/doc/haskell-aws/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
